@@ -130,7 +130,7 @@ coef.glm_hP <- function(object, ...) {
   )
 }
 
-format.perc <- function(probs, digits)
+format_perc <- function(probs, digits)
   paste(format(100 * probs, trim = TRUE, scientific = FALSE, digits = digits),
         "%")
 
@@ -166,7 +166,7 @@ confint.glm_hP <- function (object, parm, level = 0.95, ...)
   else if(is.numeric(parm)) parm <- pnames[parm]
   a <- (1 - level)/2
   a <- c(a, 1 - a)
-  pct <- format.perc(a, 3)
+  pct <- format_perc(a, 3)
   fac <- stats::qnorm(a)
   ci <- array(NA, dim = c(length(parm), 2L),
               dimnames = list(parm, pct))
